@@ -1,43 +1,56 @@
+import io
+import token
 import tokenize
 from pathlib import Path
 
 from executing import Source
+
 from inline_snapshot._format import enforce_formatting
 from inline_snapshot._format import format_code
 from inline_snapshot._utils import normalize
 from inline_snapshot._utils import simple_token
-from inline_snapshot._utils import value_to_token
 
-from ._utils import ignore_tokens
+ignore_tokens = (token.NEWLINE, token.ENDMARKER, token.NL)
+
+
+def _token_of_code(code_repr):
+    input = io.StringIO(code_repr)
+
+    return [
+        simple_token(t.type, t.string)
+        for t in tokenize.generate_tokens(input.readline)
+        if t.type not in ignore_tokens
+    ]
 
 
 class SourceFile:
-    _source = Source
+    _source: Source
 
-    def __init__(self, source):
-        if isinstance(source, SourceFile):
-            self._source = source._source
-        else:
-            self._source = source
+    def __init__(self, source: Source):
+        self._source = source
 
     @property
-    def filename(self):
+    def filename(self) -> str:
         return self._source.filename
 
-    def _format(self, text):
+    def _format(self, code):
         if self._source is None or enforce_formatting():
-            return text
+            return code
         else:
-            return format_code(text, Path(self._source.filename))
+            return format_code(code, Path(self._source.filename))
+
+    def format_expression(self, code: str) -> str:
+        return self._format(code).strip()
 
     def asttokens(self):
         return self._source.asttokens()
 
-    def _token_to_code(self, tokens):
-        return self._format(tokenize.untokenize(tokens)).strip()
+    def code_changed(self, old_node, new_code):
 
-    def _value_to_code(self, value):
-        return self._token_to_code(value_to_token(value))
+        if old_node is None:
+            return False
+
+        return self._token_of_node(old_node) != _token_of_code(new_code)
 
     def _token_of_node(self, node):
 
